@@ -4,22 +4,26 @@ import datetime
 import operator
 from collections import defaultdict
 
-from trytond.model import ModelView, fields
-from trytond.wizard import Wizard, StateView, StateAction, Button
+from trytond.model import ModelSQL, ValueMixin, fields
 from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
 from trytond.tools import grouped_slice
 
 __all__ = ['PurchaseRequest', 'PurchaseConfiguration',
-    'CreatePurchaseRequestStart', 'CreatePurchaseRequest',
-    ]
+    'PurchaseConfigurationSupplyPeriod']
+supply_period = fields.TimeDelta("Supply Period")
 
 
 class PurchaseConfiguration:
     __metaclass__ = PoolMeta
     __name__ = 'purchase.configuration'
-    supply_period = fields.Property(fields.Integer('Supply Period',
-            help='In number of days', required=True))
+    supply_period = fields.MultiValue(supply_period)
+
+
+class PurchaseConfigurationSupplyPeriod(ModelSQL, ValueMixin):
+    "Purchase Configuration Supply Period"
+    __name__ = 'purchase.configuration.supply_period'
+    supply_period = supply_period
 
 
 class PurchaseRequest:
@@ -71,13 +75,18 @@ class PurchaseRequest:
         warehouse_ids = [w.id for w in warehouses]
         # fetch order points
         order_points = OrderPoint.search([
-            ('type', '=', 'purchase'),
+            ('warehouse_location', '!=', None),
             ('company', '=', company.id if company else None),
             ])
         # index them by product
         product2ops = {}
+        product2ops_other = {}
         for order_point in order_points:
-            product2ops[
+            if order_point.type == 'purchase':
+                dict_ = product2ops
+            else:
+                dict_ = product2ops_other
+            dict_[
                 (order_point.warehouse_location.id, order_point.product.id)
                 ] = order_point
 
@@ -111,12 +120,19 @@ class PurchaseRequest:
                     min_date_qties = defaultdict(lambda: 0,
                         ((x, pbl.pop((warehouse_id, x), 0))
                             for x in product_ids))
+                    # Do not compute shortage for product
+                    # with different order point
+                    product_ids = [
+                        p.id for p in sub_products
+                        if (warehouse_id, p.id) not in product2ops_other]
                     # Search for shortage between min-max
                     shortages = cls.get_shortage(warehouse_id, product_ids,
                         min_date, max_date, min_date_qties=min_date_qties,
                         order_points=product2ops)
 
                     for product in sub_products:
+                        if product.id not in shortages:
+                            continue
                         shortage_date, product_quantity = shortages[product.id]
                         if shortage_date is None or product_quantity is None:
                             continue
@@ -220,8 +236,7 @@ class PurchaseRequest:
 
         for product_supplier in product.product_suppliers:
             supply_date = product_supplier.compute_supply_date(date=today)
-            next_day = today + datetime.timedelta(
-                product_supplier.get_supply_period())
+            next_day = today + product_supplier.get_supply_period()
             next_supply_date = product_supplier.compute_supply_date(
                 date=next_day)
             if (not min_date) or supply_date < min_date:
@@ -255,8 +270,8 @@ class PurchaseRequest:
         supplier, purchase_date = cls.find_best_supplier(product,
             shortage_date)
 
-        max_quantity = order_point and order_point.max_quantity or 0.0
-        computed_quantity = max_quantity - product_quantity
+        target_quantity = order_point.target_quantity if order_point else 0.0
+        computed_quantity = target_quantity - product_quantity
         quantity = Uom.compute_qty(product.default_uom, computed_quantity,
             product.purchase_uom or product.default_uom)
 
@@ -313,7 +328,7 @@ class PurchaseRequest:
                 min_quantity = min_quantities[product_id]
                 res_qty = res_qties.get(product_id)
                 res_date = res_dates.get(product_id)
-                if current_qty < min_quantity:
+                if min_quantity is not None and current_qty < min_quantity:
                     if not res_date:
                         res_dates[product_id] = current_date
                     if (not res_qty) or (current_qty < res_qty):
@@ -335,50 +350,3 @@ class PurchaseRequest:
 
         return dict((x, (res_dates.get(x), res_qties.get(x)))
             for x in product_ids)
-
-
-class CreatePurchaseRequestStart(ModelView):
-    'Create Purchase Request'
-    __name__ = 'purchase.request.create.start'
-
-
-class CreatePurchaseRequest(Wizard):
-    'Create Purchase Requests'
-    __name__ = 'purchase.request.create'
-    start = StateView('purchase.request.create.start',
-        'stock_supply.purchase_request_create_start_view_form', [
-            Button('Cancel', 'end', 'tryton-cancel'),
-            Button('Create', 'create_', 'tryton-ok', default=True),
-            ])
-    create_ = StateAction('purchase_request.act_purchase_request_form')
-
-    @classmethod
-    def __setup__(cls):
-        super(CreatePurchaseRequest, cls).__setup__()
-        cls._error_messages.update({
-                'late_supplier_moves': 'There are some late supplier moves.',
-                })
-
-    @property
-    def _requests_parameters(self):
-        return {}
-
-    def do_create_(self, action):
-        pool = Pool()
-        PurchaseRequest = pool.get('purchase.request')
-        Move = pool.get('stock.move')
-        Date = pool.get('ir.date')
-        today = Date.today()
-        if Move.search([
-                    ('from_location.type', '=', 'supplier'),
-                    ('to_location.type', '=', 'storage'),
-                    ('state', '=', 'draft'),
-                    ('planned_date', '<', today),
-                    ], order=[]):
-            self.raise_user_warning('%s@%s' % (self.__name__, today),
-                'late_supplier_moves')
-        PurchaseRequest.generate_requests(**self._requests_parameters)
-        return action, {}
-
-    def transition_create_(self):
-        return 'end'
